@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     Copyright (C) 2001--2020 GNUnet e.V.
+     Copyright (C) 2001--2024 GNUnet e.V.
 
      GNUnet is free software: you can redistribute it and/or modify it
      under the terms of the GNU Affero General Public License as published
@@ -1327,7 +1327,7 @@ extern "C" {
 /**
  * Service to client: result of store operation.
  */
-#define GNUNET_MESSAGE_TYPE_NAMESTORE_RECORD_STORE_RESPONSE 436
+#define GNUNET_MESSAGE_TYPE_NAMESTORE_GENERIC_RESPONSE 436
 
 /**
  * Client to service: lookup label
@@ -2352,7 +2352,7 @@ extern "C" {
 /** M<->S<->C: PSYC message which contains a header and one or more message
  * parts. */
 #define GNUNET_MESSAGE_TYPE_PSYC_MESSAGE_HEADER \
-  692 // FIXME: start using this where appropriate
+        692 // FIXME: start using this where appropriate
 
 /** Message part: method */
 #define GNUNET_MESSAGE_TYPE_PSYC_MESSAGE_METHOD 693
@@ -2599,14 +2599,14 @@ extern "C" {
 #define GNUNET_MESSAGE_TYPE_PEERSTORE_STORE 820
 
 /**
- * Iteration request
+ * Iteration request (see also 828, 829)
  */
-#define GNUNET_MESSAGE_TYPE_PEERSTORE_ITERATE 821
+#define GNUNET_MESSAGE_TYPE_PEERSTORE_ITERATE_START 821
 
 /**
- * Iteration record message
+ * Record result message
  */
-#define GNUNET_MESSAGE_TYPE_PEERSTORE_ITERATE_RECORD 822
+#define GNUNET_MESSAGE_TYPE_PEERSTORE_RECORD 822
 
 /**
  * Iteration end message
@@ -2614,19 +2614,34 @@ extern "C" {
 #define GNUNET_MESSAGE_TYPE_PEERSTORE_ITERATE_END 823
 
 /**
- * Watch request
+ * Monitor request
  */
-#define GNUNET_MESSAGE_TYPE_PEERSTORE_WATCH 824
+#define GNUNET_MESSAGE_TYPE_PEERSTORE_MONITOR_START 824
 
 /**
- * Watch response
+ * Monitor sync
  */
-#define GNUNET_MESSAGE_TYPE_PEERSTORE_WATCH_RECORD 825
+#define GNUNET_MESSAGE_TYPE_PEERSTORE_MONITOR_SYNC 825
 
 /**
- * Watch cancel request
+ * Monitor next request
  */
-#define GNUNET_MESSAGE_TYPE_PEERSTORE_WATCH_CANCEL 826
+#define GNUNET_MESSAGE_TYPE_PEERSTORE_MONITOR_NEXT 826
+
+/**
+ * Store result message
+ */
+#define GNUNET_MESSAGE_TYPE_PEERSTORE_STORE_RESULT 827
+
+/**
+ * Iteration request (see also 821, 829)
+ */
+#define GNUNET_MESSAGE_TYPE_PEERSTORE_ITERATE_NEXT 828
+
+/**
+ * Iteration request (see also 821, 828)
+ */
+#define GNUNET_MESSAGE_TYPE_PEERSTORE_ITERATE_STOP 829
 
 /*******************************************************************************
  * SOCIAL message types
@@ -3529,6 +3544,11 @@ extern "C" {
  */
 #define GNUNET_MESSAGE_TYPE_COMMUNICATOR_UDP_PAD 1461
 
+/**
+ * UDP Rekey.
+ */
+#define GNUNET_MESSAGE_TYPE_COMMUNICATOR_UDP_REKEY 1462
+
 /**
  * Next available: 1500
  */
@@ -3549,17 +3569,9 @@ extern "C" {
 
 #define GNUNET_MESSAGE_TYPE_MESSENGER_CONNECTION_CREATE 1600
 
-#define GNUNET_MESSAGE_TYPE_MESSENGER_CONNECTION_UPDATE 1601
+#define GNUNET_MESSAGE_TYPE_MESSENGER_CONNECTION_DESTROY 1601
 
-#define GNUNET_MESSAGE_TYPE_MESSENGER_CONNECTION_DESTROY 1602
-
-#define GNUNET_MESSAGE_TYPE_MESSENGER_CONNECTION_GET_NAME 1603
-
-#define GNUNET_MESSAGE_TYPE_MESSENGER_CONNECTION_SET_NAME 1604
-
-#define GNUNET_MESSAGE_TYPE_MESSENGER_CONNECTION_GET_KEY 1605
-
-#define GNUNET_MESSAGE_TYPE_MESSENGER_CONNECTION_MEMBER_ID 1606
+#define GNUNET_MESSAGE_TYPE_MESSENGER_CONNECTION_MEMBER_ID 1602
 
 /************************************  Room  *************************************/
 
@@ -3575,6 +3587,10 @@ extern "C" {
 
 #define GNUNET_MESSAGE_TYPE_MESSENGER_ROOM_GET_MESSAGE 1616
 
+#define GNUNET_MESSAGE_TYPE_MESSENGER_ROOM_SYNC 1617
+
+#define GNUNET_MESSAGE_TYPE_MESSENGER_ROOM_LINK 1618
+
 /*********************************************************************************/
 
 /*********************************************************************************/
@@ -3605,7 +3621,7 @@ extern "C" {
 
 #define GNUNET_MESSAGE_TYPE_CMDS_HELPER_BARRIER_ATTACH 1708
 
-#define GNUNET_MESSAGE_TYPE_CMDS_HELPER_BARRIER_ADVANCED 1709
+#define GNUNET_MESSAGE_TYPE_CMDS_HELPER_BARRIER_CROSSABLE 1709
 
 #define GNUNET_MESSAGE_TYPE_CMDS_HELPER_BARRIER_ATTACHED 1710
 
@@ -3618,20 +3634,19 @@ extern "C" {
  */
 
 /**
- * Message type for Begin, Commit or Rollback
+ * Message type for start of record edit with advisory lock
  */
-#define GNUNET_MESSAGE_TYPE_NAMESTORE_TX_CONTROL 1750
+#define GNUNET_MESSAGE_TYPE_NAMESTORE_RECORD_SET_EDIT 1750
 
 /**
- * Return status message for control message
+ * Return record set to edit with previous editor hint/advisory lock
  */
-#define GNUNET_MESSAGE_TYPE_NAMESTORE_TX_CONTROL_RESULT 1751
+#define GNUNET_MESSAGE_TYPE_NAMESTORE_RECORD_SET_EDIT_RESPONSE 1751
 
 /**
- * Open and lock records for editing message
+ * Message type for cancellation/reset of editor hint/advisory lock
  */
-#define GNUNET_MESSAGE_TYPE_NAMESTORE_RECORD_EDIT 1752
-
+#define GNUNET_MESSAGE_TYPE_NAMESTORE_RECORD_SET_EDIT_CANCEL 1752
 
 /**
  * Type used to match 'all' message types.
