@@ -44,6 +44,7 @@
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
+#include <inttypes.h>
 
 #ifdef __clang__
 #undef HAVE_STATIC_ASSERT
@@ -272,6 +273,10 @@ atoll (const char *nptr);
 #define EXIT_NOTRUNNING 7
 #endif
 
+#ifndef EXIT_NO_RESTART
+#define EXIT_NO_RESTART 9
+#endif
+
 /**
  * clang et al do not have such an attribute
  */
